@@ -11,12 +11,27 @@ from __future__ import absolute_import
 from redis import Redis as RedisClient
 from redis import exceptions as client_exceptions
 
-from nydus.db.backends import BaseConnection
+from nydus.db.backends import BaseConnection, BasePipeline
+
+
+class RedisPipeline(BasePipeline):
+    def __init__(self, connection):
+        self.pending = []
+        self.connection = connection
+        self.pipe = connection.pipeline()
+
+    def add(self, command):
+        self.pending.append(command)
+        getattr(self.pipe, command._attr)(*command._args, **command._kwargs)
+
+    def execute(self):
+        return self.pipe.execute()
+
 
 class Redis(BaseConnection):
-
     # Exceptions that can be retried by this backend
     retryable_exceptions = client_exceptions
+    supports_pipelines = True
 
     def __init__(self, host='localhost', port=6379, db=0, timeout=None, **options):
         self.host = host
@@ -37,6 +52,9 @@ class Redis(BaseConnection):
     def disconnect(self):
         self.connection.disconnect()
 
+    def get_pipeline(self, *args, **kwargs):
+        return RedisPipeline(self)
+
     def __getattr__(self, attr):
         if attr in self.__dict__:
             return self.__dict__[attr]
